from django.shortcuts import render, redirect
from django.conf import settings
from django.contrib import messages
from django.views.generic import View
from django.contrib.auth.mixins import LoginRequiredMixin
from django.contrib.auth import authenticate, login, logout
from .forms import LoginForm, ProfilePictureForm, SignupForm


class LoginView(View):
    dataview = dict()
    template_name = 'authentication/login.html'
    form_class = LoginForm

    def get(self, request):
        self.dataview['form'] = self.form_class()
        return render(request, self.template_name, self.dataview)

    def post(self, request):
        self.dataview['form'] = form = self.form_class(request.POST)

        if form.is_valid():
            user = authenticate(
                username=form.cleaned_data['username'],
                password=form.cleaned_data['password'],
            )
            if user is not None:
                login(request, user)
                messages.add_message(request,
                                     messages.INFO,
                                     f'Bonjour, {user.username}! Vous êtes connecté.')
                return redirect('home')
            else:
                messages.add_message(request,
                                     messages.ERROR,
                                     'Identifiants invalides.')

        return render(request, self.template_name, self.dataview)


def logout_page(request):
    logout(request)
    return redirect('login')


class SignupView(View):

    dataview = dict()
    template_name = 'authentication/signup.html'
    form_class = SignupForm

    def get(self, request):
        self.dataview['form'] = self.form_class()
        return render(request, self.template_name, self.dataview)

    def post(self, request):
        self.dataview['form'] = form = self.form_class(request.POST)
        if form.is_valid():
            user = form.save()
            login(request, user)
            return redirect(settings.LOGIN_REDIRECT_URL)
        return render(request, self.template_name, self.dataview)


class ProfilePictureView(LoginRequiredMixin, View):
    dataview = dict()
    template_name = 'authentication/profile_upload.html'
    form_class = ProfilePictureForm

    def get(self, request):
        self.dataview['form'] = self.form_class()
        return render(request, self.template_name, self.dataview)

    def post(self, request):
        self.dataview['form'] = form = self.form_class(request.POST,
                                                       request.FILES,
                                                       instance=request.user)
        if form.is_valid():
            form.save()
            messages.add_message(request,
                                 messages.INFO,
                                 'photo ajoutée avec succès')
            return redirect('home')
        return render(request, self.template_name, self.dataview)
