from django.shortcuts import render, redirect, get_object_or_404
from django.contrib.auth.decorators import login_required
from django.contrib.auth.mixins import LoginRequiredMixin
from django.http import HttpResponse, HttpResponseNotFound
from django.views.generic import View
from django.contrib import messages
from .forms import MediaForm, BlogForm
from .models import Photo, Blog


def home(request):
    dataview = dict()
    return render(request, 'blog/home.html', dataview)


def not_found(request, exception):
    print("enter not found")
    return render(request,
                  '404.html',
                  context={"exception": exception},
                  status=404)


class MediaCreateView(LoginRequiredMixin, View):
    dataview = dict()
    template_name = 'blog/media_create.html'
    form_class = MediaForm

    def get(self, request):
        self.dataview['form'] = self.form_class()
        return render(request, self.template_name, self.dataview)

    def post(self, request):
        self.dataview['form'] = form = self.form_class(request.POST,
                                                       request.FILES)
        if form.is_valid():
            photo = form.save(commit=False)
            photo.uploader = request.user
            photo.save()
            messages.add_message(request,
                                 messages.INFO,
                                 'photo ajoutée avec succès')
            return redirect('home')
        return render(request, self.template_name, self.dataview)


class PostCreateView(LoginRequiredMixin, View):
    dataview = dict()
    template_name = 'blog/post_create.html'
    blog_form_class = BlogForm
    media_form_class = MediaForm

    def get(self, request):
        self.dataview['blog_form'] = self.blog_form_class()
        self.dataview['media_form'] = self.media_form_class()
        return render(request, self.template_name, self.dataview)

    def post(self, request):
        self.dataview['blog_form'] = blog_form = self.blog_form_class(request.POST)
        self.dataview['media_form'] = media_form = self.media_form_class(request.POST,
                                                                        request.FILES)
        if all([blog_form.is_valid(), media_form.is_valid()]):
            media = media_form.save(commit=False)
            media.uploader = request.user
            media.save()
            blog_post = blog_form.save(commit=False)
            blog_post.author = request.user
            blog_post.photo = media
            blog_post.save()
            print(vars(blog_post))
            messages.add_message(request,
                                 messages.INFO,
                                 'Blog Post ajouté avec succès')
            return redirect('home')
        return render(request, self.template_name, self.dataview)


def media_list_view(request):
    dataview = dict()
    dataview['medias'] = Photo.objects.all()
    return render(request, 'blog/media_list.html', dataview)


def media_view(request, media_id):
    dataview = dict()
    dataview['media'] = get_object_or_404(Photo, id=media_id)
    return render(request, 'blog/media_view.html', dataview)


def post_list_view(request):
    dataview = dict()
    dataview['posts'] = Blog.objects.all()
    return render(request, 'blog/post_list.html', dataview)


def post_view(request, blog_id):
    dataview = dict()

    dataview['post'] = get_object_or_404(Blog, id=blog_id)

    print(vars(dataview['post']))
    return render(request, 'blog/post_view.html', dataview)
